@@ -16,4 +16,4 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-utils::globalVariables(c("SAFFL", "TRTDURGR"))
+utils::globalVariables(c("SAFFL", "TRTDURGR", "USUBJID", "AEACN"))
